"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const Mocha = require("mocha");
const chai = require("chai");
const sinon = require("sinon");
const core = require("../varsnap/core");
const expect = chai.expect;
const testCasePath = path.resolve(__dirname, '..', 'varsnap', 'test.ts');
function example(x, y) {
    return x * y;
}
core.varsnap.config = {
    varsnap: 'true',
    env: 'development',
    consumerToken: 'consumer-abcd',
};
describe('TestCase', () => {
    beforeEach(function () {
        core.Util.resetProducers();
        core.Util.resetConsumers();
        this.mocha = new Mocha({
            reporter: Mocha.reporters.Base,
        });
        this.mocha.addFile(testCasePath);
        this.mocha.unloadFiles();
    });
    it('will consume', function (done) {
        core.varsnap(example);
        const consumers = core.Util.getConsumers();
        expect(consumers.length).to.equal(1);
        const consumer = consumers[0];
        const stub = sinon.stub(consumer, 'consumeOnce');
        stub.resolves(true);
        this.mocha.run((failures) => {
            const mockConsumeOnce = consumer.consumeOnce;
            expect(mockConsumeOnce.called).to.be.true;
            expect(failures).to.equal(0);
            done();
        });
    });
    it('will error out if consume fails', function (done) {
        core.varsnap(example);
        const consumers = core.Util.getConsumers();
        expect(consumers.length).to.equal(1);
        const consumer = consumers[0];
        const stub = sinon.stub(consumer, 'consumeOnce');
        stub.resolves('asdf');
        this.mocha.run((failures) => {
            const mockConsumeOnce = consumer.consumeOnce;
            expect(mockConsumeOnce.called).to.be.true;
            expect(failures).to.equal(1);
            done();
        });
    });
});
